function [K] = conKernel(X,Y,subk,z)

%
% A convalotion kernel between X and Y using subkernel subk
%
% Usage: K = conKernel(X,Y,subk,z);
%
% Input: Data points - X, Y
%        Kernel - subk (default 2)
%                 1 Gaussian
%		  2 Linear
%                 3 Polynomial of degree z 
%        z - 
%                 If subk equals 1 z will be needed as the sigma value
%                 if subk equals 3 z will be the defaulted to 2
%
% This code makes use of the subcode kernel.m 
%
% 31/01/05 Written by David R. Hardoon drh@ecs.soton.ac.uk 
%

% setting deafults and checking for correct input
if (nargin < 2 | nargin > 4)
  disp('Incorrect number of inputs')
  K = 0; 
  help conKernel;
  return;
end

% internal variable
striK = 'polynomial';
z = 1;

if (nargin < 3)
 subk = 2;
 z = 1;
end

if (nargin == 3)
  if (subk < 1 | subk > 3)
     disp('Incorrect value for internal kernel');
	 K = 0;
	 help conKernel;
	 return;
  elseif (subk == 1)
     disp('Must input a sigma value for the Gaussian kernel');
	 K = 0;
	 help conKernel;
	 return;
  elseif (subk == 3)
     z = 2;
  end
else
  if (subk < 1 | subk > 3)
     disp('Incorrect value for internal kernel');
	 K = 0;
	 help conKernel;
	 return;
  end
  
  if (subk == 3)
     striK = 'gaussian';
  end
end

% Initialising internal data
K = 0;
xSize = size(X,1);
ySize = size(Y,1);

% Running the convolution kenerl of each point in X's gaussian with all the points in Y
% I.e. the probilitiy of the point of X 

for i=1:xSize
    for j=1:ySize
    
       %
       % One is able to introduce here conditions towards 
       % which points in X to convolove with which points in Y
       % Application and purpose dependent
       %

       K = kernel(X(i,:)',Y(j,:)',striK,z) + K;
    end
end
